@@ -152,7 +152,16 @@ class EnvironmentInterface(ABC):
     @property
     def system_python(self):
         if self._system_python is None:
-            system_python = os.environ.get(AppEnvVars.PYTHON, sys.executable)
+            system_python = os.environ.get(AppEnvVars.PYTHON)
+            if system_python == 'self':
+                system_python = sys.executable
+
+            system_python = (
+                system_python
+                or self.platform.modules.shutil.which('python')
+                or self.platform.modules.shutil.which('python3')
+                or sys.executable
+            )
             if not isabs(system_python):
                 system_python = self.platform.modules.shutil.which(system_python)
 
@@ -186,9 +195,13 @@ class EnvironmentInterface(ABC):
                         f'Environment variable `{key}` of field `tool.hatch.envs.{self.name}.env-vars` must be a string'
                     )
 
-            env_vars = env_vars.copy()
-            env_vars[AppEnvVars.ENV_ACTIVE] = self.name
-            self._env_vars = env_vars
+            new_env_vars = {}
+            with self.metadata.context.apply_context(self.context):
+                for key, value in env_vars.items():
+                    new_env_vars[key] = self.metadata.context.format(value)
+
+            new_env_vars[AppEnvVars.ENV_ACTIVE] = self.name
+            self._env_vars = new_env_vars
 
         return self._env_vars
 
